#!/bin/sh

a= . install2-init-functions

SYSTEMCTL="/bin/systemctl --no-reload"
turn_unit() {
    UNIT_TYPE=$1
    shift
    ACTION=$1
    shift
    while [ -n "$1" ]
    do
        exec_chroot ${SYSTEMCTL} ${ACTION} ${1}.${UNIT_TYPE} ||:
        shift
    done
}

DESKTOP_SESSION_NAME=webterminal
DESKTOP_SESSION=/usr/share/xsessions/${DESKTOP_SESSION_NAME}.desktop
DST_DESKTOP_SESSION=$destdir/$DESKTOP_SESSION

DST_SDDM_STATE_DIR=$destdir/var/lib/sddm
DST_SDDM_STATE_FILE=$DST_SDDM_STATE_DIR/state.conf
DST_SDDM_CONF=$destdir/etc/X11/sddm/sddm.conf
[ -e $destdir/etc/sddm/sddm.conf ] \
    && DST_SDDM_CONF=$destdir/etc/sddm/sddm.conf ||:
# setup sddm if exists
if [ -d $DST_SDDM_STATE_DIR ] ; then
    # create state file
    if ! [ -f "$DST_SDDM_STATE_FILE" ] ; then
	echo "" >$DST_SDDM_STATE_FILE ||:
	chmod 0644 $DST_SDDM_STATE_FILE ||:
	chown root:root $DST_SDDM_STATE_FILE ||:
    fi
    # setup "Last" section
    grep -q '^\[Last\]' $DST_SDDM_STATE_FILE \
	|| echo "[Last]" >>$DST_SDDM_STATE_FILE
    # set sddm session
    if [ -f $DST_DESKTOP_SESSION ] \
	#
    then
	sed -i '/^Session=/d' $DST_SDDM_STATE_FILE
	echo "Session=$DESKTOP_SESSION" >>$DST_SDDM_STATE_FILE ||:
	sed -i "s|^Session=.*|Session=$DESKTOP_SESSION_NAME|" "$DST_SDDM_CONF"
    fi
fi

LIGHTDM_STATE_DIR=/var/lib/ldm
LIGHTDM_AUTOLOGIN_FILE=/etc/lightdm/lightdm.conf.d/autologin.conf
LIGHTDM_CONF=/etc/lightdm/lightdm.conf
# setup lightdm if exists
if [ -d $destdir/$LIGHTDM_STATE_DIR ] ; then
    # set lightdm session
    if [ -f $destdir/$DESKTOP_SESSION ] \
	#
    then
	if [ -f $destdir/$LIGHTDM_CONF ] ; then
	    sed -i "s|^#*user-session=.*|user-session=$DESKTOP_SESSION_NAME|" $destdir/$LIGHTDM_CONF
	fi
	if [ -f $destdir/$LIGHTDM_AUTOLOGIN_FILE ] ; then
	    sed -i "s|^autologin-session=.*|autologin-session=$DESKTOP_SESSION_NAME|" $destdir/$LIGHTDM_AUTOLOGIN_FILE
	fi
    fi
fi

KIOSK_MODEFILE="/etc/alterator/kiosk/mode"
KIOSK_PROFILEDIR="/etc/alterator/kiosk/profiles_enabled/"
KIOSK_PROFILESTORE="/etc/alterator/kiosk/profiles/"
# setup kiosk if exists webterminal
if [ -f $DST_DESKTOP_SESSION ] ; then
    # addon profile
cat >"$destdir/$KIOSK_PROFILESTORE/webterminal-addon" <<__EOF__
U /bin/fgrep
U /usr/bin/fgrep
U /usr/bin/start-webterminal
U /bin/dbus-run-session
U /usr/bin/maliit-server
U /usr/bin/xmessage
U /usr/bin/notify-send
U /usr/bin/x-www-browser
U /usr/bin/yandex-browser-stable
U /usr/lib64/yandex/browser/yandex-browser
U /usr/lib64/yandex/browser/yandex_browser
U /usr/lib64/yandex/browser/yandex_browser-sandbox
U /usr/lib64/yandex/browser/chrome_crashpad_handler
__EOF__
    chmod 0644 "$destdir/$KIOSK_PROFILESTORE/webterminal-addon"
    # enable profiles
    for KIOSK_PROFILE in apps-common user-startup user-shutdown chromium webterminal-addon
    do
	ln -srf "$destdir/$KIOSK_PROFILESTORE/$KIOSK_PROFILE" "$destdir/$KIOSK_PROFILEDIR/$KIOSK_PROFILE"  ||:
    done
    # turn on kiosk
    mkdir -p  `dirname "$destdir/$KIOSK_MODEFILE"`
    echo "1" >$destdir/$KIOSK_MODEFILE
    turn_unit service enable kiosk ||:
fi
